@@ -12,9 +12,9 @@ import getpass
 
 # serverUrl = "http://localhost:8080/api/v1/"
 # serverUrl = "https://api.codelock.ai/api/v1/"
-serverUrl = "https://demo.api.codelock.ai/api/v1/"
+# serverUrl = "https://demo.api.codelock.ai/api/v1/"
 # serverUrl = "https://test.api.codelock.ai/api/v1/"
-# serverUrl = "https://dev.api.codelock.ai/api/v1/"
+serverUrl = "https://dev.api.codelock.ai/api/v1/"
 
 
 class CliApplication():
